@@ -1,13 +1,17 @@
-from django.conf import settings
-from django.core.management.base import BaseCommand, CommandError
-from django_extensions.management.utils import setup_logger, RedirectHandler
-from optparse import make_option
 import os
 import re
 import socket
 import sys
 import time
 
+from optparse import make_option
+
+from django.conf import settings
+from django.core.management.base import BaseCommand, CommandError
+from django_extensions.management.utils import setup_logger, RedirectHandler
+from django_extensions.management.technical_response import null_technical_500_response
+
+
 try:
     if 'django.contrib.staticfiles' in settings.INSTALLED_APPS:
         from django.contrib.staticfiles.handlers import StaticFilesHandler
@@ -20,6 +24,7 @@ try:
 except ImportError:
     USE_STATICFILES = False
 
+
 naiveip_re = re.compile(r"""^(?:
 (?P<addr>
     (?P<ipv4>\d{1,3}(?:\.\d{1,3}){3}) |         # IPv4 address
@@ -28,11 +33,10 @@ naiveip_re = re.compile(r"""^(?:
 ):)?(?P<port>\d+)$""", re.X)
 DEFAULT_PORT = "8000"
 
+
 import logging
 logger = logging.getLogger(__name__)
 
-from django_extensions.management.technical_response import null_technical_500_response
-
 
 class Command(BaseCommand):
     option_list = BaseCommand.option_list + (
@@ -44,6 +48,8 @@ class Command(BaseCommand):
                     help='Tells Django to open a browser.'),
         make_option('--adminmedia', dest='admin_media_path', default='',
                     help='Specifies the directory from which to serve admin media.'),
+        make_option('--nothreading', action='store_false', dest='threaded',
+                    help='Do not run in multithreaded mode.'),
         make_option('--threaded', action='store_true', dest='threaded',
                     help='Run in multithreaded mode.'),
         make_option('--output', dest='output_file', default=None,
@@ -80,13 +86,19 @@ class Command(BaseCommand):
         werklogger.propagate = False
 
         if options.get("print_sql", False):
-            from django.db.backends import util
+            try:
+                # Django 1.7 onwards
+                from django.db.backends import utils
+            except ImportError:
+                # Django 1.6 below
+                from django.db.backends import util as utils
+
             try:
                 import sqlparse
             except ImportError:
                 sqlparse = None  # noqa
 
-            class PrintQueryWrapper(util.CursorDebugWrapper):
+            class PrintQueryWrapper(utils.CursorDebugWrapper):
                 def execute(self, sql, params=()):
                     starttime = time.time()
                     try:
@@ -100,7 +112,7 @@ class Command(BaseCommand):
                         else:
                             logger.info(raw_sql + therest)
 
-            util.CursorDebugWrapper = PrintQueryWrapper
+            utils.CursorDebugWrapper = PrintQueryWrapper
 
         try:
             from django.core.servers.basehttp import AdminMediaHandler
@@ -112,8 +124,18 @@ class Command(BaseCommand):
             from django.core.servers.basehttp import get_internal_wsgi_application as WSGIHandler
         except ImportError:
             from django.core.handlers.wsgi import WSGIHandler  # noqa
+
         try:
             from werkzeug import run_simple, DebuggedApplication
+
+            # Set colored output
+            if settings.DEBUG:
+                try:
+                    set_werkzeug_log_color()
+                except:     # We are dealing with some internals, anything could go wrong
+                    print("Wrapping internal werkzeug logger for color highlighting has failed!")
+                    pass
+
         except ImportError:
             raise CommandError("Werkzeug is required to use runserver_plus.  Please visit http://werkzeug.pocoo.org/ or install via pip. (pip install Werkzeug)")
 
@@ -153,7 +175,7 @@ class Command(BaseCommand):
         if not self.addr:
             self.addr = '::1' if self.use_ipv6 else '127.0.0.1'
 
-        threaded = options.get('threaded', False)
+        threaded = options.get('threaded', True)
         use_reloader = options.get('use_reloader', True)
         open_browser = options.get('open_browser', False)
         cert_path = options.get("cert_path")
@@ -233,3 +255,47 @@ class Command(BaseCommand):
                 ssl_context=ssl_context
             )
         inner_run()
+
+
+def set_werkzeug_log_color():
+    """Try to set color to the werkzeug log.
+    """
+    from django.core.management.color import color_style
+    from werkzeug.serving import WSGIRequestHandler
+    from werkzeug._internal import _log
+
+    _style = color_style()
+    _orig_log = WSGIRequestHandler.log
+
+    def werk_log(self, type, message, *args):
+        try:
+            msg = '%s - - [%s] %s' % (
+                self.address_string(),
+                self.log_date_time_string(),
+                message % args,
+            )
+            http_code = str(args[1])
+        except:
+            return _orig_log(type, message, *args)
+
+        # Utilize terminal colors, if available
+        if http_code[0] == '2':
+            # Put 2XX first, since it should be the common case
+            msg = _style.HTTP_SUCCESS(msg)
+        elif http_code[0] == '1':
+            msg = _style.HTTP_INFO(msg)
+        elif http_code == '304':
+            msg = _style.HTTP_NOT_MODIFIED(msg)
+        elif http_code[0] == '3':
+            msg = _style.HTTP_REDIRECT(msg)
+        elif http_code == '404':
+            msg = _style.HTTP_NOT_FOUND(msg)
+        elif http_code[0] == '4':
+            msg = _style.HTTP_BAD_REQUEST(msg)
+        else:
+            # Any 5XX, or any other response
+            msg = _style.HTTP_SERVER_ERROR(msg)
+
+        _log(type, msg)
+
+    WSGIRequestHandler.log = werk_log
